@@ -21,10 +21,9 @@
 #' @export
 #' @examples
 #' HEAD("http://google.com")
-#' HEAD("http://google.com")$headers
+#' headers(HEAD("http://google.com"))
 HEAD <- function(url = NULL, config = list(), ..., handle = NULL) {
   hu <- handle_url(handle, url, ...)
-  config <- make_config(config, ..., list(nobody = TRUE))
-
-  make_request("head", hu$handle, hu$url, config)
+  req <- request_build("HEAD", hu$url, config, ..., config(nobody = TRUE))
+  request_perform(req, hu$handle$handle)
 }
